@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Action;
 BEGIN {
-  $Net::CLI::Interact::Action::VERSION = '1.111150';
+  $Net::CLI::Interact::Action::VERSION = '1.111500';
 }
 
 use Moose;
@@ -15,7 +15,7 @@ has 'type' => (
 
 has 'value' => (
     is => 'ro',
-    isa => 'Str|RegexpRef',
+    isa => 'Str|RegexpRef|ArrayRef[RegexpRef]',
     required => 1,
 );
 
@@ -106,7 +106,7 @@ Net::CLI::Interact::Action - Sent data or matched response from connected device
 
 =head1 VERSION
 
-version 1.111150
+version 1.111500
 
 =head1 DESCRIPTION
 
@@ -133,7 +133,9 @@ Denotes the kind of Action, which may be C<send> or C<match>.
 =head2 value
 
 In the case of C<send>, a String command to send to the device. In the case of
-C<match>, a regular expression reference to match response from the device.
+C<match>, a regular expression reference to match response from the device. In
+special circumstances an array reference of regular expression references is
+also valid, and each will be checked for a match against the device response.
 
 =head2 no_ors
 
