@@ -1,11 +1,10 @@
 package Net::CLI::Interact::Transport::Base;
-{
-  $Net::CLI::Interact::Transport::Base::VERSION = '1.122020_002';
+BEGIN {
+  $Net::CLI::Interact::Transport::Base::VERSION = '1.111500';
 }
 
 use Moose;
 use Moose::Util::TypeConstraints;
-with 'Net::CLI::Interact::Role::FindMatch';
 
 {
     package # hide from pause
@@ -13,27 +12,27 @@ with 'Net::CLI::Interact::Role::FindMatch';
     use Moose;
 }
 
-has 'use_net_telnet_connection' => (
-    is => 'rw',
-    isa => 'Int',
-    default => 0,
-);
-
 has 'logger' => (
     is => 'ro',
     isa => 'Net::CLI::Interact::Logger',
     required => 1,
 );
 
-has 'irs_re' => (
+has 'irs' => (
     is => 'ro',
-    isa => 'RegexpRef',
-    default => sub { qr/(?:\015\012|\015|\012)/ }, # first wins
+    isa => 'Str',
+    default => "\n",
     required => 0,
 );
 
+sub irs_re {
+    my $self = shift;
+    my $irs = $self->irs;
+    return qr/$irs/;
+}
+
 has 'ors' => (
-    is => 'rw',
+    is => 'ro',
     isa => 'Str',
     default => "\n",
     required => 0,
@@ -99,42 +98,52 @@ sub buffer { _abc() }
 
 sub DEMOLISH { (shift)->disconnect }
 
+# see if any regexp in the arrayref match the response
+sub _first_match {
+    my ($text, $matches) = @_;
+    $matches = ((ref $matches eq ref qr//) ? [$matches] : $matches);
+    return undef unless
+        (scalar grep {ref $_ eq ref qr//} @$matches) == scalar @$matches;
+
+    use List::Util 'first';
+    return first { $text =~ $_ } @$matches;
+}
+
 sub do_action {
     my ($self, $action) = @_;
     $self->logger->log('transport', 'info', 'callback received for', $action->type);
 
     if ($action->type eq 'match') {
-        my $irs_re = $self->irs_re;
         my $cont = $action->continuation;
-
         while ($self->pump) {
-            # remove control characters
-            (my $buffer = $self->buffer) =~ s/[\000-\010\013\014\016-\037]//g;
-            $self->logger->log('dump', 'debug', "SEEN:\n". $buffer);
+            $self->logger->log('dump', 'debug', "SEEN:\n". $self->buffer);
 
-            if ($buffer =~ m/^(.*$irs_re)(.*)/s) {
-                $self->stash($self->stash . $1);
-                $self->buffer($2 || '');
-            }
+            my @out_lines = split $self->irs_re, $self->buffer;
+            next if !defined $out_lines[-1];
 
-            if ($cont and $self->find_match($self->buffer, $cont->first->value)) {
+            my $maybe_stash = join $self->irs, @out_lines[0 .. ($#out_lines - 1)];
+            my $last_out = $out_lines[-1];
+
+            if ($cont and $last_out =~ $cont->first->value) {
                 $self->logger->log('transport', 'debug', 'continuation matched');
-                $self->buffer('');
+                $self->stash($self->flush);
                 $self->put($cont->last->value);
             }
-            elsif (my $hit = $self->find_match($self->buffer, $action->value)) {
+            elsif (my $hit = _first_match($last_out, $action->value)) {
                 $self->logger->log('transport', 'debug',
                     sprintf 'output matched %s, storing and returning', $hit);
-                $action->prompt_hit($hit);
-                $action->response_stash($self->stash);
-                $action->response($self->buffer);
-                $self->flush;
+                # prompt match is line oriented. want to split that off from
+                # rest of output which is marshalled into the 'send'.
+                my @output = split $self->irs_re, $self->flush;
+                $action->response_stash(join $self->irs, @output[0 .. ($#output - 1)]);
+                $action->response($output[-1]);
                 last;
             }
             else {
-                $self->logger->log('transport', 'debug', "nope, doesn't (yet) match",
-                    (ref $action->value eq ref [] ? (join '|', @{$action->value})
-                                                : $action->value));
+                $self->logger->log('transport', 'debug', "nope, doesn't (yet) match", $action->value);
+                # put back the partial output and try again
+                $self->stash( $self->stash . $maybe_stash );
+                $self->buffer($last_out);
             }
         }
     }
