@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Transport::Base::Unix;
-{
-  $Net::CLI::Interact::Transport::Base::Unix::VERSION = '1.122020_002';
+BEGIN {
+  $Net::CLI::Interact::Transport::Base::Unix::VERSION = '1.111500';
 }
 
 use Moose;
@@ -21,6 +21,18 @@ extends 'Net::CLI::Interact::Transport::Base';
     );
 }
 
+has '+irs' => (
+    trigger => sub {
+        (shift)->wrapper->input_record_separator(shift) if scalar @_ > 1;
+    },
+);
+
+has '+ors' => (
+    trigger => sub {
+        (shift)->wrapper->output_record_separator(shift) if scalar @_ > 1;
+    },
+);
+
 sub put { (shift)->wrapper->put( join '', @_ ) }
 
 has '_buffer' => (
@@ -39,7 +51,7 @@ sub buffer {
 sub pump {
     my $self = shift;
     my $content = $self->wrapper->get;
-    $self->_buffer($self->_buffer . $content) if defined $content;
+    $self->_buffer($self->_buffer . $content);
 }
 
 has '+timeout' => (
@@ -52,6 +64,12 @@ has '+wrapper' => (
     isa => 'Net::Telnet',
 );
 
+has 'use_net_telnet_connection' => (
+    is => 'rw',
+    isa => 'Int',
+    default => 0,
+);
+
 override '_build_wrapper' => sub {
     my $self = shift;
 
